@@ -15,12 +15,11 @@ BEGIN {
 my $client = new Tapper::Installer::Base;
 $client->system_install("");
 
-
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -39,17 +38,26 @@ Tapper::Installer::Base which cares for the rest.
 
 tapper-installer-client.pl - control the installation and setup of an automatic test system
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
