@@ -1,14 +1,9 @@
 package Tapper::Installer;
-# git description: v4.1.0-1-gbb7ee4f
+# git description: v4.1.1-6-g129f830
 
-BEGIN {
-  $Tapper::Installer::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Installer::VERSION = '4.1.1';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Install everything needed for a test
-
+$Tapper::Installer::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -46,9 +41,10 @@ sub logdie
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -66,17 +62,26 @@ Tell the MCP server our current status, then die().
 
 @param string - message to send to MCP
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
