@@ -1,11 +1,6 @@
 package Tapper::Installer::Base;
-BEGIN {
-  $Tapper::Installer::Base::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Installer::Base::VERSION = '4.1.1';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Installer::Base::VERSION = '5.0.0';
 use Moose;
 
 use common::sense;
@@ -250,11 +245,11 @@ sub system_install
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -322,17 +317,26 @@ Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
