@@ -1,11 +1,6 @@
 package Tapper::Installer::Precondition::Fstab;
-BEGIN {
-  $Tapper::Installer::Precondition::Fstab::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Installer::Precondition::Fstab::VERSION = '4.1.1';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Installer::Precondition::Fstab::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -36,9 +31,10 @@ sub install {
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -63,17 +59,26 @@ Install a file from an nfs share.
 @return success - 0
 @return error   - error string
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
