@@ -1,11 +1,6 @@
 package Tapper::Installer::Precondition::Image;
-BEGIN {
-  $Tapper::Installer::Precondition::Image::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Installer::Precondition::Image::VERSION = '4.1.1';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Installer::Precondition::Image::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -404,9 +399,10 @@ sub unmount
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -576,7 +572,7 @@ Install an image of type tar.gz.
 @param int    - size of the target partition
 @param string - device name of the target partition
 @param string - directory to mount the installed image to
-@param string - partition labe
+@param string - partition label
 
 @return success - 0
 @return error   - error string
@@ -589,7 +585,7 @@ Install an image of type tar.bz2.
 @param int    - size of the target partition
 @param string - device name of the target partition
 @param string - directory to mount the installed image to
-@param string - partition labe
+@param string - partition label
 
 @return success - 0
 @return error   - error string
@@ -613,17 +609,26 @@ order.
 @return success - 0
 @return error   - error string
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
