@@ -1,11 +1,6 @@
 package Tapper::Installer::Precondition::Kernelbuild;
-BEGIN {
-  $Tapper::Installer::Precondition::Kernelbuild::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Installer::Precondition::Kernelbuild::VERSION = '4.1.1';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Installer::Precondition::Kernelbuild::VERSION = '5.0.0';
 
 use Moose;
 use IO::Handle; # needed to set pipe nonblocking
@@ -263,9 +258,10 @@ sub install
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -344,17 +340,26 @@ kernel and initrd file.
 @return success - 0
 @return error   - error string
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
