@@ -1,11 +1,6 @@
 package Tapper::Installer::Precondition::PRC;
-BEGIN {
-  $Tapper::Installer::Precondition::PRC::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Installer::Precondition::PRC::VERSION = '4.1.1';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Installer::Precondition::PRC::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -236,9 +231,10 @@ sub get_distro
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -329,17 +325,26 @@ distribution
 @return success - name of the distro
 @return error   - empty string
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
