@@ -1,11 +1,6 @@
 package Tapper::Installer::Precondition::Package;
-BEGIN {
-  $Tapper::Installer::Precondition::Package::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Installer::Precondition::Package::VERSION = '4.1.1';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Installer::Precondition::Package::VERSION = '5.0.0';
 use strict;
 use warnings;
 use 5.010;
@@ -22,8 +17,7 @@ sub install
         my ($self, $package) = @_;
         if ($package->{url}) {
                 my ($proto, $fullpath) = $package->{url} =~ m|^(\w+)://(.+)$|;
-                given($proto) {
-                        when ('nfs') {
+                if ($proto eq 'nfs') {
                                 my $nfs_dir='/mnt/nfs';
                                 $self->makedir($nfs_dir);
                                 my $path = dirname $fullpath;
@@ -36,8 +30,7 @@ sub install
                                 ($error, $retval) = $self->log_and_exec("umount $nfs_dir");
                                 return 0;
                         }
-                        default { return ("Procol'$proto' is not supported") }
-                }
+                        else { return ("Procol'$proto' is not supported") }
         }
 
 
@@ -63,46 +56,45 @@ sub install
 
         my $output;
         $self->log->debug("type is $type");
-        given($type){
-                when("gzip") {
+        if ($type eq "gzip") {
                         ($error, $output) = $self->log_and_exec("tar --no-same-owner -C $basedir -xzf $pkg");
                         return("can't unpack package $filename: $output\n") if $error;
                 }
-                when("tar") {
+                elsif ($type eq "tar") {
                         ($error, $output) = $self->log_and_exec("tar --no-same-owner -C $basedir -xf $pkg");
                         return("can't unpack package $filename: $output\n") if $error;
                 }
-                when("bz2") {
+                elsif ($type eq "bz2") {
                         ($error, $output) = $self->log_and_exec("tar --no-same-owner -C $basedir -xjf $pkg");
                         return("can't unpack package $filename: $output\n") if $error;
                 }
-                when("deb") {
+                elsif ($type eq "deb") {
                         system("cp $pkg $basedir/");
                         $pkg = basename $pkg;
                         my $exec = Tapper::Installer::Precondition::Exec->new($self->cfg);
                         return $exec->install({command => "dpkg -i $pkg"});
                 }
-                when("rpm") {
+                elsif ($type eq "rpm") {
                         system("cp $pkg $basedir/");
                         $pkg = basename $pkg;
                         my $exec = Tapper::Installer::Precondition::Exec->new($self->cfg);
                         # use -U to overwrite possibly existing	older package
                         return $exec->install({command => "rpm -U  $pkg"});
                 }
-                default{
+                else {
                         $self->log->warn(qq($pkg is of unrecognised file type "$type"));
                         return(qq($pkg is of unrecognised file type "$type"));
                 }
-        }
         return(0);
 }
 
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -132,17 +124,26 @@ Recognised options for package preconditions are:
 @return success - 0
 @return error   - error string
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
